@@ -1,7 +1,7 @@
 import unittest
 
-from zope.testing import doctestunit
-from zope.component import testing
+#from zope.testing import doctestunit
+#from zope.component import testing
 from Testing import ZopeTestCase as ztc
 
 from Products.Five import zcml
